@@ -1,5 +1,6 @@
 from .message import Message
 from .requests.added_chat_participant import AddedChatParticipant
+from .requests.changed_participant_role import ChangedParticipantRole
 from .requests.created_channel import CreatedChannel
 from .requests.created_group_chat import CreatedGroupChat
 from .requests.created_personal_chat import CreatedPersonalChat
@@ -9,9 +10,15 @@ from .requests.removed_chat_participant import RemovedChatParticipant
 from .requests.removed_message import RemovedMessage
 from .requests.uploading_progress import UploadingProgress
 from .update import Update
+from .input_file import InputFile
+from .input_file import BufferedInputFile
+from .input_file import FSInputFile
+from .input_file import URLInputFile
+
 
 __all__ = [
     "AddedChatParticipant",
+    "ChangedParticipantRole",
     "CreatedChannel",
     "CreatedGroupChat",
     "CreatedPersonalChat",
@@ -22,4 +29,8 @@ __all__ = [
     "RemovedMessage",
     "Update",
     "UploadingProgress",
+    "InputFile",
+    "BufferedInputFile",
+    "FSInputFile",
+    "URLInputFile",
 ]
